##################
jax_verify Documentation
##################

.. toctree::
   :maxdepth: 2
   :hidden:

   api
   sdp_verify

``jax_verify`` is a library for verification of neural network specifications.

Installation
============

Install ``jax_verify`` by running::

  $ pip install jax_verify

Support
=======

If you are having issues, please let us know by filing an issue on our
`issue tracker <https://github.com/deepmind/jax_verify/issues>`_.

License
=======

jax_verify is licensed under the Apache 2.0 License.
